@@ -1,7 +1,6 @@
 from deployer.console import confirm, input
-from deployer.contrib.services.apt_get import AptGet
 from deployer.exceptions import ExecCommandFailed
-from deployer.service import Service, map_roles, isolate_host, dont_isolate_yet, ServiceBase, required_property, default_action
+from deployer.service import Service, isolate_host, dont_isolate_yet, ServiceBase, required_property, default_action
 from deployer.utils import esc1
 import termcolor
 
@@ -55,6 +54,7 @@ class Git(Service):
 
     repository = required_property()
     repository_location = required_property()
+    default_revision = 'default'
 
     commands = { } # Extra git commands. Map function name to git command.
 
@@ -66,7 +66,7 @@ class Git(Service):
 
         # If no commit was given, ask for commit.
         if not commit:
-            commit = input('Git commit', default='master')
+            commit = input('Git commit', default=self.default_revision)
             if not commit: raise Exception('No commit given')
 
         self._checkout(commit)
