@@ -1,14 +1,9 @@
-import datetime
-import os
-import readline
 import socket
-import string
 import sys
 import termcolor
-import time
 import traceback
 
-from deployer.cli import CLInterface, Handler, HandlerType, ExitCLILoop
+from deployer.cli import CLInterface, Handler, HandlerType
 from deployer.exceptions import ExecCommandFailed, QueryException
 from deployer.service import ActionException
 from deployer.console import lesspipe, in_columns
@@ -19,6 +14,8 @@ from pygments import highlight
 from pygments.formatters import TerminalFormatter as Formatter
 from pygments.lexers import PythonTracebackLexer
 
+from inspect import getfile
+
 __all__ = ('Shell', )
 
 
@@ -147,7 +144,7 @@ class Version(ShellHandler):
     is_leaf = True
     handler_type = BuiltinType()
 
-    def __call__(self, context):
+    def __call__(self):
         print termcolor.colored('  deployer library, version: ', 'cyan'),
         print termcolor.colored(deployer.__version__, 'red')
         print termcolor.colored('  Host:                      ', 'cyan'),
@@ -209,7 +206,7 @@ class Do(ShellHandler):
 
 
 @create_navigable_handler
-def Find(self, context):
+def Find(self):
     def _list_nested_services(service, prefix):
         for name, action in service.get_actions():
             yield '%s %s' % (prefix, termcolor.colored(name, service.get_group().color))
@@ -222,10 +219,9 @@ def Find(self, context):
 
     lesspipe(_list_nested_services(self.service, ''), self.shell.pty)
 
-from inspect import getfile
 
 @create_navigable_handler
-def Inspect(self, context):
+def Inspect(self):
     """
     Inspection of the current service. Show host mappings and other information.
     """
@@ -314,12 +310,12 @@ def Inspect(self, context):
 
 
 @create_navigable_handler
-def Cd(self, context):
+def Cd(self):
     self.shell.state.cd(self.service)
 
 
 @create_navigable_handler
-def Ls(self, context):
+def Ls(self):
     """
     List subservices and actions in the current service.
     """
@@ -354,7 +350,7 @@ class Exit(ShellHandler):
     is_leaf = True
     handler_type = BuiltinType()
 
-    def __call__(self, context):
+    def __call__(self):
         self.shell.exit()
 
 
@@ -365,7 +361,7 @@ class Return(ShellHandler):
     is_leaf = True
     handler_type = BuiltinType()
 
-    def __call__(self, context):
+    def __call__(self):
         self.shell.state = self.shell.state.return_state
 
 
@@ -376,7 +372,7 @@ class Clear(ShellHandler):
     is_leaf = True
     handler_type = BuiltinType()
 
-    def __call__(self, context):
+    def __call__(self):
         sys.stdout.write('\033[2J\033[0;0H')
         sys.stdout.flush()
 
@@ -439,9 +435,9 @@ class Service(Handler):
         elif name == '&' and self.is_leaf:
             return Action(self.service.get_action(self.service._default_action), self.shell, self.sandbox, fork=True)
 
-    def __call__(self, context):
+    def __call__(self):
         if self.service._default_action:
-            return Action(self.service.get_action(self.service._default_action), self.shell, self.sandbox).__call__(context)
+            return Action(self.service.get_action(self.service._default_action), self.shell, self.sandbox).__call__()
 
 
 class Action(Handler):
@@ -464,16 +460,16 @@ class Action(Handler):
         else:
             return type_of_action(self.action)
 
-    def __call__(self, context):
+    def __call__(self):
         if self.fork:
             def action(pty):
-                self._run_action(context, pty)
+                self._run_action(pty)
 
             self.shell.pty.run_in_auxiliary_ptys(action)
         else:
-            self._run_action(context, self.shell.pty)
+            self._run_action(self.shell.pty)
 
-    def _run_action(self, context, pty):
+    def _run_action(self, pty):
         # Execute
         sandbox = self.sandbox
         logger_interface = self.shell.logger_interface
@@ -669,8 +665,8 @@ class ShellState(object):
             prefix = ''
 
         return prefix + termcolor.colored('.', 'green').join(
-			termcolor.colored(s._name or '', s.get_group().color) for s in
-						self._service._path + [self._service])
+            termcolor.colored(s._name or '', s.get_group().color) for s in
+                        self._service._path + [self._service])
 
     def cd(self, target_service):
         self._prev_service = self._service
